@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: postgresql-libpq
-version: 0.8.2.5
-id: postgresql-libpq-0.8.2.5-deac34083c872f6845400600404988d2
+version: 0.9.0.1
+id: postgresql-libpq-0.9.0.1-090b3eef19460778fbfb5ff7cba74ba1
 
 license: BSD3
 copyright: (c) 2010 Grant Monroe
@@ -24,22 +24,21 @@ exposed: True
 exposed-modules: Database.PostgreSQL.LibPQ
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/postgresql-libpq-0.8.2.5
-library-dirs: /usr/local/lib/ghc/postgresql-libpq-0.8.2.5
+import-dirs: /usr/local/lib/ghc/postgresql-libpq-0.9.0.1
+library-dirs: /usr/local/lib/ghc/postgresql-libpq-0.9.0.1
               /usr/local/lib
-hs-libraries: HSpostgresql-libpq-0.8.2.5
-extra-libraries: crypto ssl com_err asn1 krb5 wind roken heimbase
-                 pq
+hs-libraries: HSpostgresql-libpq-0.9.0.1
+extra-libraries: crypto ssl pq
 extra-ghci-libraries:
 include-dirs: /usr/local/include/postgresql
 includes:
-depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
-         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
+depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-postgresql-libpq-0.8.2.5/html/postgresql-libpq.haddock
-haddock-html: /usr/local/share/doc/hs-postgresql-libpq-0.8.2.5/html
+haddock-interfaces: /usr/local/share/doc/hs-postgresql-libpq-0.9.0.1/html/postgresql-libpq.haddock
+haddock-html: /usr/local/share/doc/hs-postgresql-libpq-0.9.0.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
